"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var CodeMirror = require("codemirror");
require("codemirror/mode/markdown/markdown");
require("codemirror/mode/gfm/gfm");
require("codemirror/mode/yaml/yaml");
require("codemirror/mode/toml/toml");
require("codemirror/mode/javascript/javascript");
require("codemirror/addon/scroll/simplescrollbars");
require("codemirror/addon/scroll/annotatescrollbar");
require("codemirror/addon/search/search");
require("codemirror/addon/search/searchcursor");
require("codemirror/addon/search/jump-to-line");
require("codemirror/addon/search/match-highlighter");
require("codemirror/addon/search/matchesonscrollbar");
require("codemirror/addon/display/fullscreen");
require("codemirror/addon/fold/markdown-fold");
require("codemirror/addon/selection/active-line");
require("codemirror/addon/mode/overlay");
require("codemirror/addon/dialog/dialog");
require("codemirror/addon/edit/closetag");
require("codemirror/addon/edit/continuelist");
require("codemirror/addon/fold/foldcode");
require("codemirror/addon/fold/foldgutter");
require("codemirror/mode/meta");
require("codemirror/mode/yaml-frontmatter/yaml-frontmatter");
require("./toml-frontmatter");
require("./json-frontmatter");
var useEffect = React.useEffect, useRef = React.useRef;
var defaultOptions = {
    mode: 'yaml-frontmatter',
    autoScroll: true,
    tabSize: 2,
    styleActiveLine: true,
    indentWithTabs: true,
    lineWrapping: true,
    lineNumbers: true,
    foldGutter: true,
    scrollbarStyle: 'simple',
    highlightSelectionMatches: { showToken: /\w/, annotateScrollbar: true },
    extraKeys: { 'Alt-F': 'findPersistent', 'Ctrl-M': 'replaceShift' }
};
var cnPhrases = {
    'Search:': '搜索:',
    '(Use /re/ syntax for regexp search)': '(使用 /re/ 语法进行正则式搜索)',
    'Replace?': '替换？',
    'Replace:': '替换:',
    'Replace all:': '全部替换:',
    'With:': '为:',
    'Yes:': '是',
    'No:': '否',
    'All:': '所有',
    'Stop:': '停止',
    'Jump to line:': '跳转到行:',
    '(Use line:column or scroll% syntax)': '(使用 行号:列号 或 滚动比例% 语法)'
};
var mapHandlers = function (props, cm) {
    var handlerNames = Object.keys(props).filter(function (prop) {
        return /^on+/.test(prop);
    });
    for (var _i = 0, handlerNames_1 = handlerNames; _i < handlerNames_1.length; _i++) {
        var handlerName = handlerNames_1[_i];
        var cmEvent = handlerName.replace(/^on[A-Z]/g, function (s) {
            return s.slice(2).toLowerCase();
        });
        cm.on(cmEvent, props[handlerName]);
    }
};
var EditorCore = React.memo(function (props) {
    var _a = React.useState(null), mounted = _a[0], setMounted = _a[1];
    useEffect(function () {
        var options = props.options, intlPhrases = props.intlPhrases, locale = props.locale, atMounted = props.atMounted, atUnmounted = props.atUnmounted, atChange = props.atChange;
        var gutters = props.lineNumers
            ? ['CodeMirror-linenumbers', 'CodeMirror-foldgutter']
            : [];
        var composedOptions = intlPhrases
            ? locale === 'zh-CN'
                ? __assign({}, options, { phrases: __assign({}, cnPhrases, intlPhrases), gutters: gutters }) : __assign({}, options, { phrases: intlPhrases, gutters: gutters })
            : locale === 'zh-CN'
                ? __assign({}, options, { phrases: cnPhrases, gutters: gutters }) : __assign({}, options, { gutters: gutters });
        var cm = mounted ||
            CodeMirror(cmEle.current, __assign({}, defaultOptions, composedOptions));
        if (!mounted) {
            setMounted(cm);
            if (options && options.value)
                cm.setValue(options.value);
            var composedProps = atChange
                ? __assign({}, props, { onChange: function (editor, change) { return atChange(cm, change, editor.getDoc().getValue()); } }) : props;
            mapHandlers(composedProps, cm);
            if (atMounted)
                atMounted(cm);
        }
        return function () { return atUnmounted && atUnmounted(cm); };
    });
    var cmEle = useRef(null);
    var composedClassName = 'pro-markdown-codemirror' + (props.className ? ' ' + props.className : '');
    return React.createElement("div", { className: composedClassName, ref: cmEle });
});
exports.default = EditorCore;
//# sourceMappingURL=EditorCore.js.map