"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var EditorCore_1 = require("./EditorCore");
var MenuItem_1 = require("./MenuItem");
var Helper = require("./helpers");
var MarkdownPreview_1 = require("./MarkdownPreview");
var EditorStates = {
    editing: 'editing',
    preview: 'preview',
    splitpane: 'splitpane'
};
var ProMarkdown = function (props) {
    if (props.mode &&
        props.mode.name !== 'yaml-frontmatter' &&
        props.mode.name !== 'toml-frontmatter' &&
        props.mode.name !== 'json-frontmatter' &&
        props.mode.base !== 'markdown' &&
        props.mode.base !== 'gfm')
        throw new Error('Current only supports yaml-frontmatter mode, tom-frontmatter and json-fromtmatter modes, with gfm or markdown as base mode');
    var locale = props.locale === 'zh-CN' ? 'zh-CN' : 'en-US';
    var _a = React.useState({ left: 0, top: 0 }), scroll = _a[0], setScroll = _a[1];
    var _b = React.useState({ line: 0, ch: 0 }), cursor = _b[0], setCursor = _b[1];
    var _c = React.useState(props.initialValue || ''), value = _c[0], setValue = _c[1];
    var _d = React.useState(null), codemirror = _d[0], setCodemirror = _d[1];
    var _e = React.useState({}), textState = _e[0], setTextState = _e[1];
    var _f = React.useState(false), fullScreen = _f[0], setFullScreen = _f[1];
    var _g = React.useState('editing'), editorState = _g[0], setEditorState = _g[1];
    var savePosition = function () {
        if (codemirror) {
            var pos = codemirror.getScrollInfo();
            var cursorZ = codemirror.getDoc().getCursor();
            setScroll({ left: pos.left, top: pos.top });
            setCursor({ line: cursorZ.line, ch: cursorZ.ch });
        }
    };
    var editing = function () { return editorState === 'editing' || editorState === 'splitpane'; };
    var iHandlers = {
        bold: function () {
            return editing() && codemirror && Helper.toggleBold(codemirror, textState);
        },
        br: function () {
            return editing() &&
                codemirror &&
                Helper.drawHorizontalRule(codemirror, textState);
        },
        eraser: function () { return editing() && codemirror && Helper.cleanBlock(codemirror); },
        heading: function () { return editing() && codemirror && Helper.toggleHeading(codemirror); },
        italic: function () {
            return editing() && codemirror && Helper.toggleItalic(codemirror, textState);
        },
        link: function () {
            return editing() && codemirror && Helper.drawLink(codemirror, textState);
        },
        image: function () {
            return editing() && codemirror && Helper.drawImage(codemirror, textState);
        },
        table: function () {
            return editing() && codemirror && Helper.drawTable(codemirror, textState);
        },
        code: function () { return editing() && codemirror && Helper.toggleCodeBlock(codemirror); },
        'ordered-list': function () {
            return editing() &&
                codemirror &&
                Helper.toggleOrderedList(codemirror, textState);
        },
        'unordered-list': function () {
            return editing() &&
                codemirror &&
                Helper.toggleUnorderedList(codemirror, textState);
        },
        quote: function () {
            return editing() && codemirror && Helper.toggleQuote(codemirror, textState);
        },
        strikethrough: function () {
            return editing() &&
                codemirror &&
                Helper.toggleStrikethrough(codemirror, textState);
        },
        preview: function () {
            if (editorState === EditorStates.preview)
                setEditorState(EditorStates.editing);
            else {
                savePosition();
                setEditorState(EditorStates.preview);
            }
        },
        fullscreen: function () {
            if (editorState === EditorStates.editing)
                savePosition();
            if (editorState === EditorStates.splitpane) {
                savePosition();
                setEditorState(EditorStates.editing);
            }
            setFullScreen(!fullScreen);
        },
        splitpane: function () {
            if (editorState === EditorStates.splitpane) {
                savePosition();
                setEditorState(EditorStates.editing);
                return;
            }
            if (!fullScreen)
                setFullScreen(true);
            if (editorState === EditorStates.editing)
                savePosition();
            setEditorState(EditorStates.splitpane);
        }
    };
    var defaultMenuCN = [
        {
            name: 'bold',
            tip: (props.menuitemTips && props.menuitemTips['bold']) || '加黑'
        },
        {
            name: 'italic',
            tip: (props.menuitemTips && props.menuitemTips['italic']) || '斜体'
        },
        {
            name: 'strikethrough',
            tip: (props.menuitemTips && props.menuitemTips['strikethrough']) || '删除'
        },
        {
            name: 'heading',
            tip: (props.menuitemTips && props.menuitemTips['heading']) || '标题'
        },
        {
            name: '|',
            tip: ''
        },
        {
            name: 'quote',
            tip: (props.menuitemTips && props.menuitemTips['quote']) || '引用'
        },
        {
            name: 'code',
            tip: (props.menuitemTips && props.menuitemTips['code']) || '代码'
        },
        {
            name: 'unordered-list',
            tip: (props.menuitemTips && props.menuitemTips['unordered-list']) || '列表'
        },
        {
            name: 'ordered-list',
            tip: (props.menuitemTips && props.menuitemTips['ordered-list']) || '排序列表'
        },
        {
            name: '|',
            tip: ''
        },
        {
            name: 'link',
            tip: (props.menuitemTips && props.menuitemTips['link']) || '链接'
        },
        {
            name: 'image',
            tip: (props.menuitemTips && props.menuitemTips['image']) || '图片'
        },
        {
            name: 'table',
            tip: (props.menuitemTips && props.menuitemTips['table']) || '表格'
        },
        {
            name: 'br',
            tip: (props.menuitemTips && props.menuitemTips['br']) || '水平分割线'
        },
        {
            name: '|',
            tip: ''
        },
        {
            name: 'preview',
            tip: (props.menuitemTips && props.menuitemTips['preview']) || '预览'
        },
        {
            name: 'splitpane',
            tip: (props.menuitemTips && props.menuitemTips['splitpane']) ||
                '编辑 & 实时预览'
        },
        {
            name: 'fullscreen',
            tip: (props.menuitemTips && props.menuitemTips['fullscreen']) || '全屏'
        },
        {
            name: '|',
            tip: ''
        },
        {
            name: 'help',
            tip: (props.menuitemTips && props.menuitemTips['help']) || '帮助'
        }
    ];
    var defaultMenuEN = [
        {
            name: 'bold',
            tip: (props.menuitemTips && props.menuitemTips['bold']) || 'Toggle bold'
        },
        {
            name: 'italic',
            tip: (props.menuitemTips && props.menuitemTips['italic']) || 'Toggle italic'
        },
        {
            name: 'strikethrough',
            tip: (props.menuitemTips && props.menuitemTips['strikethrough']) ||
                'Toggle strikethrough'
        },
        {
            name: 'heading',
            tip: (props.menuitemTips && props.menuitemTips['heading']) ||
                'Toggle heading'
        },
        {
            name: '|',
            tip: ''
        },
        {
            name: 'quote',
            tip: (props.menuitemTips && props.menuitemTips['quote']) || 'Toggle quote'
        },
        {
            name: 'code',
            tip: (props.menuitemTips && props.menuitemTips['code']) || 'Toggle code'
        },
        {
            name: 'unordered-list',
            tip: (props.menuitemTips && props.menuitemTips['unordered-list']) ||
                'Toggle unordered list'
        },
        {
            name: 'ordered-list',
            tip: (props.menuitemTips && props.menuitemTips['ordered-list']) ||
                'Toggle ordered list'
        },
        {
            name: '|',
            tip: ''
        },
        {
            name: 'link',
            tip: (props.menuitemTips && props.menuitemTips['link']) || 'Link'
        },
        {
            name: 'image',
            tip: (props.menuitemTips && props.menuitemTips['image']) || 'Image'
        },
        {
            name: 'table',
            tip: (props.menuitemTips && props.menuitemTips['table']) || 'Table'
        },
        {
            name: 'br',
            tip: (props.menuitemTips && props.menuitemTips['br']) || 'Horizontal rule'
        },
        {
            name: '|',
            tip: ''
        },
        {
            name: 'preview',
            tip: (props.menuitemTips && props.menuitemTips['preview']) || 'Preview'
        },
        {
            name: 'splitpane',
            tip: (props.menuitemTips && props.menuitemTips['splitpane']) ||
                'Edit & live preview'
        },
        {
            name: 'fullscreen',
            tip: (props.menuitemTips && props.menuitemTips['fullscreen']) || 'Fullscreen'
        },
        {
            name: '|',
            tip: ''
        },
        {
            name: 'help',
            tip: (props.menuitemTips && props.menuitemTips['help']) || 'Help'
        }
    ];
    var defaultMenu = locale === 'zh-CN' ? defaultMenuCN : defaultMenuEN;
    var mode = props.mode || {
        name: 'yaml-frontmatter',
        base: 'gfm'
    };
    var menuItem = props.menu && props.menu.length > 0 ? props.menu : defaultMenu;
    var atMounted = function (cm) {
        setCodemirror(cm);
        cm.scrollTo(scroll.left, scroll.top);
        cm.getDoc().setCursor(cursor.line, cursor.ch);
        cm.focus();
    };
    var atUnmounted = function (cm) {
        setValue(cm.getDoc().getValue());
    };
    var atChange = function (cm, change, valueArg) {
        setValue(valueArg);
    };
    var onCursorActivity = function (cm) {
        var textStateZ = Helper.getTextState(cm);
        setTextState(textStateZ);
    };
    var menu = props.hideMenu ? null : (React.createElement("div", { className: 'pro-markdown-menu' }, menuItem.map(function (item, index) {
        var name = item.name, onClick = item.onClick;
        var state = 'enabled';
        switch (name) {
            case 'bold':
            case 'br':
            case 'code':
            case 'eraser':
            case 'heading':
            case 'image':
            case 'italic':
            case 'link':
            case 'ordered-list':
            case 'quote':
            case 'table':
            case 'strikethrough':
            case 'unordered-list':
                state = textState[name] ? 'selected' : 'enabled';
                break;
            case 'fullscreen':
                state = fullScreen ? 'selected' : 'enabled';
                break;
            default:
                state = editorState === name ? 'selected' : 'enabled';
        }
        return (React.createElement("span", { key: index, className: 'pro-markdown-icon-wrap' }, name === '|' ? (React.createElement(MenuItem_1.default, __assign({}, item, { editor: codemirror, state: state }))) : (React.createElement(MenuItem_1.default, __assign({}, item, { editor: codemirror, onClick: onClick || iHandlers[name], state: state })))));
    })));
    var editorProps = {
        options: {
            value: value,
            mode: mode,
            lineNumbers: typeof props.lineNumbers === undefined ? true : props.lineNumbers
        },
        locale: locale,
        atMounted: atMounted,
        atUnmounted: atUnmounted,
        atChange: atChange,
        onCursorActivity: onCursorActivity
    };
    var wrapperClassName = 'pro-markdown ' +
        (fullScreen ? 'pro-markdown-fullscreen' : 'pro-markdown-normal');
    var editor;
    switch (editorState) {
        case EditorStates.preview: {
            if (props.renderPreview)
                editor = props.renderPreview({ value: value });
            else {
                var source = value || '';
                var trans = props.markdownTransformer
                    ? props.markdownTransformer
                    : Helper.frontmatterTransformer;
                var transed = trans(source);
                editor = React.createElement(MarkdownPreview_1.default, { source: transed });
            }
            return (React.createElement("div", { className: wrapperClassName },
                menu,
                editor));
        }
        case EditorStates.splitpane: {
            var preview = void 0;
            if (props.renderPreview)
                preview = props.renderPreview({ value: value });
            else {
                var source = value || '';
                var trans = props.markdownTransformer
                    ? props.markdownTransformer
                    : Helper.frontmatterTransformer;
                var transed = trans(source);
                preview = React.createElement(MarkdownPreview_1.default, { className: 'markdown-body', source: transed });
            }
            editor = React.createElement(EditorCore_1.default, __assign({}, editorProps));
            return (React.createElement("div", { className: wrapperClassName },
                menu,
                React.createElement("div", { className: 'pro-markdown-splitwrap' },
                    React.createElement("div", { className: 'pro-markdown-splitpane-editor' }, editor),
                    React.createElement("div", { className: 'pro-markdown-splitpane-preview' }, preview))));
        }
        default: {
            editor = React.createElement(EditorCore_1.default, __assign({}, editorProps));
            return (React.createElement("div", { className: wrapperClassName },
                menu,
                editor));
        }
    }
};
exports.default = ProMarkdown;
//# sourceMappingURL=ProMarkdown.js.map