"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var Enzyme = require("enzyme");
var Adapter = require("enzyme-adapter-react-16");
var enzyme_1 = require("enzyme");
var Sinon = require("sinon");
var ProMarkdown_1 = require("./ProMarkdown");
Enzyme.configure({ adapter: new Adapter() });
describe("ProMarkdown default", function () {
    var wrapper = enzyme_1.render(React.createElement(ProMarkdown_1.default, { className: "my-promarkdown" }));
    test("ProMarkdown root is mounted correctly", function () {
        expect(wrapper.is('.pro-markdown')).toBeTruthy();
    });
    test("ProMarkdown rendered correctly", function () {
        expect(wrapper).toMatchSnapshot();
    });
    test("EditorCore is mounted correctly", function () {
        expect(wrapper.find('.pro-markdown-codemirror').length).toBe(1);
    });
    test("Menu is mounted correctly", function () {
        expect(wrapper.find('.pro-markdown-menu').length).toBe(1);
    });
    test("Default menu icons are rendered correctly", function () {
        expect(wrapper.find('.pro-markdown-icon-wrap').length).toBe(20);
    });
});
describe("ProMarkdown custom menu", function () {
    var fakeClick = Sinon.fake();
    var fakeClickLink = Sinon.fake();
    var menu = [
        {
            name: 'bold',
            tip: 'Make it bold'
        },
        {
            name: 'italic',
            tip: 'italic',
            render: function () { return React.createElement("div", null, " Italic "); },
            onClick: function (editor, name, state) {
                return console.log('italic clicked', editor, name, state);
            }
        },
        {
            name: 'link',
            tip: 'Link',
            className: 'icon-link',
            render: function () { return React.createElement("div", null, " Link "); },
            onClick: fakeClickLink
        },
        {
            name: 'mycommand',
            tip: 'myCommand',
            className: 'icon-my-command',
            render: function () { return React.createElement("div", null, " My comman "); },
            onClick: function (editor, name, state) {
                return console.log('mycomman', editor, name, state);
            }
        },
        {
            name: 'bold-spy',
            tip: 'Bold spy',
            className: 'icon-bold-spy',
            render: function () { return React.createElement("div", { className: "custom-rendered" }, " Italic "); },
            onClick: fakeClick
        },
    ];
    var props = { menu: menu };
    var wrapper = enzyme_1.shallow(React.createElement(ProMarkdown_1.default, __assign({}, props, { className: "my-promarkdown" })));
    test("Custom menu icons are rendered correctly", function () {
        expect(wrapper.find('.pro-markdown-icon-wrap').length).toBe(5);
    });
    test("Custom menu icon with classname is rendered correctly", function () {
        expect(wrapper.find('.icon-my-command').length).toBe(1);
    });
    it("calls set formating on click on standard menu item with custom handler", function () {
        wrapper.find(".icon-link")
            .simulate("click");
        expect(fakeClickLink.calledOnce).toBe(true);
    });
    it("calls set formating on click on custom menu item", function () {
        wrapper.find(".icon-bold-spy")
            .simulate("click");
        expect(fakeClick.calledOnce).toBe(true);
    });
});
//# sourceMappingURL=ProMarkdown.test.js.map